@@ -16,4 +16,4 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-sync_schema_props_perms('type')
+sync_schema_props_perms('DrugTake', 'unit', 'String')
